<?php

namespace Drupal\membership\Entity;

use Drupal\Core\Entity\EntityWithPluginCollectionInterface;
use Drupal\Core\Entity\RevisionableEntityBundleInterface;
use Drupal\membership\Plugin\MembershipProviderInterface;

/**
 * Provides an interface for defining Membership type entities.
 */
interface MembershipTypeInterface extends RevisionableEntityBundleInterface, EntityWithPluginCollectionInterface {

  /**
   * @return string
   */
  public function getWorkflowId();

  /**
   * Getter for the plugin ID.
   *
   * @return string
   *   Plugin ID.
   */
  public function getPluginId(): ?string;

  /**
   * Get the plugin.
   *
   * @return \Drupal\membership\Plugin\MembershipProviderInterface
   *   The config entity's backing plugin.
   */
  public function getPlugin(): MembershipProviderInterface;

  /**
   * Set the plugin.
   *
   * @param string $plugin_id
   *   The plugin ID.
   *
   * @return $this
   */
  public function setPluginId(string $plugin_id);

  /**
   * Gets the membership provider plugin configuration.
   *
   * @return array
   *   The membership provider plugin configuration.
   */
  public function getPluginConfiguration();

  /**
   * Sets the membership provider plugin configuration.
   *
   * @param array $configuration
   *   The payment gateway plugin configuration.
   *
   * @return $this
   */
  public function setPluginConfiguration(array $configuration);

  /**
   * Create a membership of this type, with the provider plugin involved.
   *
   * @param array $values
   *   Entity values to pass through.
   * @param array $providerData
   *   Provider-specific data to be passed to the plugin.
   *
   * @return \Drupal\membership\Entity\MembershipInterface
   *   The created, saved membership.
   */
  public function createMembership(array $values, array $providerData = []);

}
