<?php declare(strict_types=1);

namespace Drupal\membership;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Repository for memberships.
 */
class MembershipRepository implements MembershipRepositoryInterface {

  /**
   * Cache of enabled statuses.
   *
   * @var bool[]
   */
  protected static array $enabledCache = [];

  /**
   * Membership storage.
   *
   * @var \Drupal\membership\MembershipStorageInterface
   */
  protected MembershipStorageInterface $membershipStorage;

  /**
   * @inheritDoc
   */
  public function __construct(protected EntityTypeManagerInterface $entityTypeManager) {
    $this->membershipStorage = $this->entityTypeManager->getStorage('membership');
  }

  /**
   * {@inheritDoc}
   */
  public function loadMultipleForAccount(AccountInterface $account, bool $active = TRUE): array {
    $query = $this->membershipStorage
      ->getQuery()
      ->accessCheck(FALSE)
      ->condition('user_id', $account->id());
    if ($active) {
      $query->condition('state', 'active');
    }
    return $this->membershipStorage->loadMultiple($query->execute());
  }

  /**
   * {@inheritDoc}
   */
  public function hasActive(AccountInterface $account): bool {
    if (!array_key_exists($account->id(), self::$enabledCache)) {
      self::$enabledCache[$account->id()] =
        (bool) $this->entityTypeManager->getStorage('membership')
          ->getQuery()
          ->condition('user_id', $account->id())
          ->condition('state', 'active')
          ->accessCheck(FALSE)
          ->count()
          ->execute();
    }
    return self::$enabledCache[$account->id()];
  }

  /**
   * Clear the enabled cache.
   *
   * @return void
   */
  public static function clearEnabledCache(): void {
    self::$enabledCache = [];
  }

}
