<?php declare(strict_types=1);

namespace Drupal\membership;

use Drupal\Core\Session\AccountInterface;

interface MembershipRepositoryInterface {

  /**
   * Load memberships for a user.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   User account.
   * @param bool $active
   *   Whether to filter by only active memberships.
   *
   * @return \Drupal\membership\Entity\MembershipInterface[]
   *   Memberships. May or may not be active.
   */
  public function loadMultipleForAccount(AccountInterface $account, bool $active = TRUE): array;

  /**
   * Determine if a user has active membership(s).
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   Account.
   *
   * @return bool
   *   TRUE if the user has active memberships, FALSE if not.
   */
  public function hasActive(AccountInterface $account): bool;

}
